@@ -187,9 +187,13 @@ def _set_conn_read_only(conn):
         print(f"couldn't set read-only mode on connection: {conn.__class__.__name__}")
 
 
-def dataframe_to_sql(dataframe, table_name: str, append: bool=False):
+def dataframe_to_sql(dataframe, table_name: str, append: bool=False, flavor: str=None):
     """
     Generate SQL statements to create a table and add data.
+    :param dataframe:   A dataframe to render into SQL.
+    :param table_name:  Name of table to create or extend.
+    :param append:      True to append, False to replace.
+    :param flavor:      Name of a particular type of database, to adjust details of SQL format.
     :returns a generator of (sql, parameter list)
     """
     def enquote(name):
@@ -199,11 +203,16 @@ def dataframe_to_sql(dataframe, table_name: str, append: bool=False):
         return name
     if not append:
         yield "DROP TABLE IF EXISTS %s" % enquote(table_name), []
-    dtype_to_sql = {"int64": "INTEGER", "float64": "DOUBLE PRECISION"}
+    if flavor == "bigquery":
+        dtype_to_sql = {"int64": "INT64", "float64": "NUMERIC"}
+        str_type = "STRING"
+    else:
+        dtype_to_sql = {"int64": "INTEGER", "float64": "DOUBLE PRECISION"}
+        str_type = "VARCHAR"
     cols = list(dataframe.columns)
     types = []
     for col, dtype in zip(cols, dataframe.dtypes):
-        sql_type = dtype_to_sql.get(str(dtype)) or f"VARCHAR({dataframe[col].str.len().max()+3})"
+        sql_type = dtype_to_sql.get(str(dtype)) or f"{str_type}({dataframe[col].str.len().max()+3:d})"
         types.append(sql_type)
     rows = dataframe.itertuples(index=False, name=None)
     fields = ", ".join("%s %s" % (enquote(col), t) for col, t in zip(cols, types))
