@@ -51,6 +51,15 @@ class TestConnect(unittest.TestCase):
             ('INSERT INTO t1 (x, y, z) VALUES (%s, %s, %s), (%s, %s, %s), (%s, %s, %s)', [1, 1.0, 'one', 2, 2.0, 'two', 3, 4.0, 'three'])
         ])
 
+    def test_dataframe_to_sql__bigquery(self):
+        df = pandas.DataFrame({"x": [1, 2, 3], "y": [1.0, 2.0, 4.0], "z": ["one", "two", "three"]})
+        sqls = list(dataframe_to_sql(df, "t1", flavor="bigquery"))
+        self.assertEqual(sqls, [
+            ('DROP TABLE IF EXISTS t1', []),
+            ('CREATE TABLE IF NOT EXISTS t1 (x INT64, y NUMERIC, z STRING(8))', []),
+            ('INSERT INTO t1 (x, y, z) VALUES (%s, %s, %s), (%s, %s, %s), (%s, %s, %s)', [1, 1.0, 'one', 2, 2.0, 'two', 3, 4.0, 'three'])
+        ])
+
     def test_db_conn_flavor(self):
         # artificially set property
         class A(object):
